pub struct PayerReport {
pub originator_node_id: u32,
pub start_sequence_id: u64,
pub end_sequence_id: u64,
pub end_minute_since_epoch: u32,
pub payers_merkle_root: Vec<u8>,
pub active_node_ids: Vec<u32>,
}Expand description
A report of the payers and nodes that sent messages in a given range of messages
Fields
originator_node_id: u32The originator this report is referring to
start_sequence_id: u64The sequence_id that the report starts at [exclusive]
end_sequence_id: u64The sequence_id that the report ends at [inclusive]
end_minute_since_epoch: u32The end timestamp of the report
payers_merkle_root: Vec<u8>The merkle root of the payer balance diff tree
active_node_ids: Vec<u32>The node IDs that are active in the network at the time of the report