pub struct UnsignedOriginatorEnvelope {
pub originator_node_id: u32,
pub originator_sequence_id: u64,
pub originator_ns: i64,
pub payer_envelope_bytes: Vec<u8>,
pub base_fee_picodollars: u64,
pub congestion_fee_picodollars: u64,
pub expiry_unixtime: u64,
}Expand description
For blockchain envelopes, these fields are set by the smart contract
Fields
originator_node_id: u32originator_sequence_id: u64originator_ns: i64payer_envelope_bytes: Vec<u8>base_fee_picodollars: u64The base fee for the message in picodollars
congestion_fee_picodollars: u64The congestion fee for the message in picodollars
expiry_unixtime: u64Trait Implementations
Sourceimpl Clone for UnsignedOriginatorEnvelope
impl Clone for UnsignedOriginatorEnvelope
Sourcefn clone(&self) -> UnsignedOriginatorEnvelope
fn clone(&self) -> UnsignedOriginatorEnvelope
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnsignedOriginatorEnvelope
impl Debug for UnsignedOriginatorEnvelope
Sourceimpl Default for UnsignedOriginatorEnvelope
impl Default for UnsignedOriginatorEnvelope
impl<'de> Deserialize<'de> for UnsignedOriginatorEnvelope
impl<'de> Deserialize<'de> for UnsignedOriginatorEnvelope
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for UnsignedOriginatorEnvelope
impl Hash for UnsignedOriginatorEnvelope
Sourceimpl Message for UnsignedOriginatorEnvelope
impl Message for UnsignedOriginatorEnvelope
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Name for UnsignedOriginatorEnvelope
impl Name for UnsignedOriginatorEnvelope
Sourceconst NAME: &'static str = "UnsignedOriginatorEnvelope"
const NAME: &'static str = "UnsignedOriginatorEnvelope"
Simple name for this
Message.
This name is the same as it appears in the source .proto file, e.g. FooBar.Sourceconst PACKAGE: &'static str = "xmtp.xmtpv4.envelopes"
const PACKAGE: &'static str = "xmtp.xmtpv4.envelopes"
Package name this message type is contained in. They are domain-like
and delimited by
., e.g. google.protobuf.Sourcefn full_name() -> String
fn full_name() -> String
Fully-qualified unique name for this
Message.
It’s prefixed with the package name and names of any parent messages,
e.g. google.rpc.BadRequest.FieldViolation.
By default, this is the package name followed by the message name.
Fully-qualified names must be unique within a domain of Type URLs.Sourceimpl PartialEq for UnsignedOriginatorEnvelope
impl PartialEq for UnsignedOriginatorEnvelope
Sourcefn eq(&self, other: &UnsignedOriginatorEnvelope) -> bool
fn eq(&self, other: &UnsignedOriginatorEnvelope) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Serialize for UnsignedOriginatorEnvelope
impl Serialize for UnsignedOriginatorEnvelope
impl Eq for UnsignedOriginatorEnvelope
impl StructuralPartialEq for UnsignedOriginatorEnvelope